@@ -1,10 +1,11 @@
 ﻿/*
- * SPDX-FileCopyrightText: 2014-2022 Megan Conkle <megan.conkle@kdemail.net>
+ * SPDX-FileCopyrightText: 2014-2023 Megan Conkle <megan.conkle@kdemail.net>
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include <QApplication>
+#include <QDebug>
 #include <QDir>
 #include <QFile>
 #include <QFileDialog>
@@ -12,22 +13,23 @@
 #include <QFileSystemWatcher>
 #include <QMessageBox>
 #include <QPair>
-#include <QString>
 #include <QStandardPaths>
+#include <QString>
 #include <QTextDocument>
 #include <QTextStream>
 #include <QTimer>
 
-#include "asynctextwriter.h"
+#include "editor/asynctextwriter.h"
+#include "editor/markdowndocument.h"
+#include "editor/markdowneditor.h"
+#include "export/exportdialog.h"
+#include "export/exporter.h"
+#include "export/exporterfactory.h"
+#include "theme/themerepository.h"
+
 #include "library.h"
 #include "documentmanager.h"
-#include "exportdialog.h"
-#include "exporter.h"
-#include "exporterfactory.h"
-#include "markdowndocument.h"
-#include "markdowneditor.h"
 #include "messageboxhelper.h"
-#include "themerepository.h"
 
 namespace ghostwriter
 {
@@ -54,6 +56,7 @@ public:
     const QString draftName = DocumentManager::tr("untitled");
 
     QString draftLocation;
+    QString backupLocation;
 
     DocumentManager *q_ptr;
     MarkdownDocument *document;
@@ -327,6 +330,19 @@ void DocumentManager::setDraftLocation(const QString &directory)
     d->draftLocation = draftDir.absolutePath();
 }
 
+void DocumentManager::setBackupLocation(const QString &directory)
+{
+    Q_D(DocumentManager);
+
+    QDir backupDir(directory);
+
+    if (!backupDir.exists()) {
+        backupDir.mkpath(backupDir.path());
+    }
+
+    d->backupLocation = backupDir.absolutePath();
+}
+
 void DocumentManager::setFileHistoryEnabled(bool enabled)
 {
     Q_D(DocumentManager);
@@ -937,7 +953,21 @@ bool DocumentManagerPrivate::checkPermissionsBeforeSave()
 
 void DocumentManagerPrivate::backupFile(const QString &filePath) const
 {
-    QString backupFilePath = filePath + ".backup";
+    QFile f(filePath);
+    QFileInfo fileInfo(f.fileName());
+    QString fileName(fileInfo.fileName());
+
+    QString backupFilePath = this->backupLocation + QDir::separator() + fileName + ".backup";
+
+    QDir backupDir(this->backupLocation);
+
+    if (!backupDir.exists()) {
+        if (!backupDir.mkpath(this->backupLocation)) {
+            MessageBoxHelper::critical(this->editor, DocumentManager::tr("File backup failed"), DocumentManager::tr("Error creating backup location!"));
+            return;
+        }
+    }
+
     QFile backupFile(backupFilePath);
 
     if (backupFile.exists()) {
